//-------------------------------------------------------------------------------------------------
//
// File        : clockGen.v
//
// Description : This is a clock generator module. It also asserts a reset signal for 2 cycles.  
// Parameters:
//      resetClocks : Length of reset in clock cycles
//		period : Length of a clock cycle
//		number : Number of clock cycles to generate before stopping
//               0 means run essentially forever
//
//-------------------------------------------------------------------------------------------------
`timescale 1ns / 1ns

module clockGen 
  (output reg clk,
   output reg reset);

   localparam resetClocks = 2;
   localparam period = 10;	// 10ns clock period by default
   localparam number = 1000000;	// 1000000 clock cycles by default

   integer 	  i;

   initial	begin
	  clk = 0;
	  reset = 1;
	  #(period+1);
	  for (i = 1; i != number; i = i + 1) begin
		 clk = 1;
		 #(period/2) clk = 0;
		 if (i==resetClocks) reset = 0;
		 #(period - period/2) ;
	  end
	  $stop; 
   end

endmodule
